# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/cms/article/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/cms/article/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Cms\\Article\\": "packages/cms/article/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Cms\Article\Providers\ArticleServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Article'  => Cms\Article\Facades\Article::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Cms\\ArticleTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Cms\Article\Providers\ArticleServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Cms\Article\Providers\ArticleServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Cms\Article\Providers\ArticleServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/article/{modulename}

**User**

    http://path-to-route-folder/user/article/{modulename}

**Public**

    http://path-to-route-folder/articles


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/article/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/article/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/article/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/article/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/article/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/article/{modulename}/{slug}
    METHOD: GET